#!/usr/local/bin/perl -w

########################################################################
########################################################################
##                                                                    ##
## Phat - a system for predicting gene structures in DNA.             ##
## Copyright (C) 2000 Simon Cawley and Anthony Wirth                  ##
##                                                                    ##
## This program is free software; you can redistribute it and/or      ##
## modify it under the terms of the GNU General Public License        ##
## as published by the Free Software Foundation; either version 2     ##
## of the License, or (at your option) any later version.             ##
##                                                                    ##
## This program is distributed in the hope that it will be useful,    ##
## but WITHOUT ANY WARRANTY; without even the implied warranty of     ##
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the      ##
## GNU General Public License for more details.                       ##
##                                                                    ##
## You should have received a copy of the GNU General Public License  ##
## along with this program; if not, write to the Free Software        ##
## Foundation, Inc.,                                                  ##
## 59 Temple Place - Suite 330,                                       ##
## Boston, MA  02111-1307, USA.                                       ##
##                                                                    ##
########################################################################
########################################################################

use Bio::Seq;
use Bio::SeqIO;

##
##
##
sub buildStopcodonModel {
  my($inFile) = shift;
  my($outFile) = shift;
  my($verbose) = shift;

  my(%count,$inSeq,$seqObj,$n,$end,$name);

  $count{"TAA"} = 0;
  $count{"TAG"} = 0;
  $count{"TGA"} = 0;

  $inSeq = Bio::SeqIO->new(-file => $inFile);
  while($seqObj = $inSeq->next_seq()) {
    $n = $seqObj->length;
    $end = $seqObj->subseq($n-2,$n);
    $end = uc($end);
    if(! exists($count{$end})) {
      $name = $seqObj->display_id();
      print STDERR "Warning: unexpected last three bases for $name: $end (ignoring it)\n";
    } else {
      $count{$end} += 1;
    }
  }

  open(OUTFILE,">$outFile") || die "Can't open $outFile for write\n";
  printf OUTFILE ("%6d TAA\n",$count{"TAA"});
  printf OUTFILE ("%6d TAG\n",$count{"TAG"});
  printf OUTFILE ("%6d TGA\n",$count{"TGA"});
  close OUTFILE;

  return;
}

1

