/***********************************************************************
************************************************************************
**                                                                    **
** Phat - a system for predicting gene structures in DNA.             **
** Copyright (C) 2000 Simon Cawley and Anthony Wirth                  **
**                                                                    **
** This program is free software; you can redistribute it and/or      **
** modify it under the terms of the GNU General Public License        **
** as published by the Free Software Foundation; either version 2     **
** of the License, or (at your option) any later version.             **
**                                                                    **
** This program is distributed in the hope that it will be useful,    **
** but WITHOUT ANY WARRANTY; without even the implied warranty of     **
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the      **
** GNU General Public License for more details.                       **
**                                                                    **
** You should have received a copy of the GNU General Public License  **
** along with this program; if not, write to the Free Software        **
** Foundation, Inc.,                                                  **
** 59 Temple Place - Suite 330,                                       **
** Boston, MA  02111-1307, USA.                                       **
**                                                                    **
************************************************************************
***********************************************************************/

#ifndef HEADER_SEQ
#define HEADER_SEQ 1

int readSequence(Option *option);
int getSeqLen(char *inFile);
int getSeqFormat(char *inFile);
void openSeq(FILE **seqFile, char *inFrie, int format);
char getNextBase(FILE **seqFile, int format);
void locateBounds(Option *option);
int viterbi(Option *option);           /* computes mygamma (for viterbi) and alpha (forward vars) */
void backward(Option *option);              /* computes beta (backward variables) */
void writeProbFile(int nBases, Option *opt);

/* 
** The following four functions do summations/maximizations involved in the
** forward and Viterbi calculations.
*/
double endforward(int t,double deltaMaxB,Option *option);
double startbackward(int t,double deltaMaxB,Option *option);
double donorforward(int t, int state, double deltaMaxB, Option *option);
double acceptorbackward(int pos, int state, double maxp, Option *option);

void startforward(int t, Option *option);
void endbackward(int t, Option *option);
void acceptorforward(int t, int state, Option *option);
void donorbackward(int t, int state, Option *option);

void doBackTrack(int startstate, int tStart, Gene *gene, int *nGenes, Option *option);
void printBestExon(int i,int t);
Gene *storeGene(Gene *gene, int i, int t, int *geneCount, Option *option);
int  base2num(int c);
char *getGenomicSeqPointer(void);
void writeFwdProbFile(int nBases, Option *opt);
void writeBakProbFile(int nBases, Option *opt);
double round(double x, int n);
void testFunction(void);

#endif
