/***********************************************************************
************************************************************************
**                                                                    **
** Phat - a system for predicting gene structures in DNA.             **
** Copyright (C) 2000 Simon Cawley and Anthony Wirth                  **
**                                                                    **
** This program is free software; you can redistribute it and/or      **
** modify it under the terms of the GNU General Public License        **
** as published by the Free Software Foundation; either version 2     **
** of the License, or (at your option) any later version.             **
**                                                                    **
** This program is distributed in the hope that it will be useful,    **
** but WITHOUT ANY WARRANTY; without even the implied warranty of     **
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the      **
** GNU General Public License for more details.                       **
**                                                                    **
** You should have received a copy of the GNU General Public License  **
** along with this program; if not, write to the Free Software        **
** Foundation, Inc.,                                                  **
** 59 Temple Place - Suite 330,                                       **
** Boston, MA  02111-1307, USA.                                       **
**                                                                    **
************************************************************************
***********************************************************************/

#ifndef HEADER_SPLICE
#define HEADER_SPLICE 1

/*
** Stuff relating to reading splice site data and returning
** splice site scores
*/


typedef struct {
  double probs[N_BASES];
} Probs;

typedef struct {
  int order;
  int nContexts;
  Probs *context;
} MM;

typedef struct {
  int max_order;
  int nPos;
  MM *pos;
} Splice_mm;

void readAcceptorData(char *filename, Option *option);
void readDonorData(char *filename, Option *option);
int readSpliceData(char *filename, Splice_mm *mm, int *up_str, int *dn_str, Option *option);
void normalizeArray(double *array, int dim1, int dim2);

void accLookupInit(int nBases, int nFor, int nBak, Option *option);
void donLookupInit(int nBases, int nFor, int nBak, Option *option);

double scoreAcceptor(char *seq, int pos, int dir);
double scoreDonor(char *seq, int pos, int dir);
double calcAccScore(char *seq, int dir);
double calcDonScore(char *seq, int dir);
double score_mm(Splice_mm mm,char *seq,int nSkip, int skipOffset, int dir);


#endif
