/***********************************************************************
************************************************************************
**                                                                    **
** Phat - a system for predicting gene structures in DNA.             **
** Copyright (C) 2000 Simon Cawley and Anthony Wirth                  **
**                                                                    **
** This program is free software; you can redistribute it and/or      **
** modify it under the terms of the GNU General Public License        **
** as published by the Free Software Foundation; either version 2     **
** of the License, or (at your option) any later version.             **
**                                                                    **
** This program is distributed in the hope that it will be useful,    **
** but WITHOUT ANY WARRANTY; without even the implied warranty of     **
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the      **
** GNU General Public License for more details.                       **
**                                                                    **
** You should have received a copy of the GNU General Public License  **
** along with this program; if not, write to the Free Software        **
** Foundation, Inc.,                                                  **
** 59 Temple Place - Suite 330,                                       **
** Boston, MA  02111-1307, USA.                                       **
**                                                                    **
************************************************************************
***********************************************************************/

#ifndef HEADER_SEQ
#define HEADER_SEQ 1

int readSequence(Option *option);
int getSeqLen(char *inFile);
int getSeqFormat(char *inFile);
void openSeq(FILE **seqFile, char *inFrie, int format);
char getNextBase(FILE **seqFile, int format);
void reverseSequence(Option *option);
void locateBounds(Option *option);
int viterbi(Option *option);           /* computes mygamma (for viterbi) and alpha (forward vars) */
void backward(Option *option);              /* computes beta (backward variables) */
double endforward(int pos, double maxp, Option *option);               /* used in forward/viterbi calculations */
double donorforward(int pos, int state, double maxp, Option *option);  /* used in forward/viterbi calculations */
void startforward(int pos, Option *option);                          /* used in backward calculations */
void acceptorforward(int pos, int state, Option *option);            /* used in backward calculations */
void doBackTrack(int startstate, int startpos, Gene *gene, int *nGenes, Option *option);
void printBestExon(int i,int t);
Gene *storeGene(Gene *gene, int i, int t, int *geneCount, Option *option);
int  base2num(int c);
char *getGenomicSeqPointer(void);
void writeFwdProbFile(int nBases, Option *opt);
void writeBakProbFile(int nBases, Option *opt);
double round(double x, int n);
void testFunction(void);
#endif
